@@ -4,7 +4,7 @@
 
 package Mason::Compilation;
 BEGIN {
-  $Mason::Compilation::VERSION = '2.13';
+  $Mason::Compilation::VERSION = '2.14';
 }
 use File::Basename qw(dirname);
 use Guard;
@@ -453,7 +453,7 @@ method _match_apply_filter () {
     my $pos = pos( $self->{source} );
 
     # Match % ... {{ at beginning of line
-    if ( $self->{source} =~ / \G (?<=^) % ([^\n]*) \{\{ \n /gcmx ) {
+    if ( $self->{source} =~ / \G (?<=^) % ([^\n]*) \{\{ \s* (?:\#.*)? \n /gcmx ) {
         my ($filter_expr) = ($1);
         $self->_handle_apply_filter($filter_expr);
         return 1;
@@ -483,7 +483,7 @@ method _match_apply_filter () {
 }
 
 method _match_apply_filter_end () {
-    if ( $self->{source} =~ / \G (?<=^) % [ \t]+ \}\} (?:\n\n?|\z) /gmcx ) {
+    if ( $self->{source} =~ / \G (?<=^) % [ \t]+ \}\} \s* (?:\#.*)? (?:\n\n?|\z) /gmcx ) {
         if ( $self->{current_method}->{type} eq 'apply_filter' ) {
             $self->{end_parse} = pos( $self->{source} );
             return 1;
@@ -881,8 +881,9 @@ This class has no public API at this time.
 =head1 MODIFIABLE METHODS
 
 These methods are not intended to be called externally, but may be useful to
-modify with method modifiers in plugins and subclasses. We will attempt to keep
-their APIs stable.
+modify with method modifiers in L<plugins|Mason::Manual::Plugins> and
+L<subclasses|<Mason::Manual::Subclasses>. Their APIs will be kept as stable as
+possible.
 
 =over
 
