@@ -1,6 +1,6 @@
 package Mason::Component;
 BEGIN {
-  $Mason::Component::VERSION = '2.13';
+  $Mason::Component::VERSION = '2.14';
 }
 use Moose;    # no Mason::Moose - don't want StrictConstructor
 use MooseX::HasDefaults::RO;
@@ -164,15 +164,11 @@ C<wrap> using C<method> instead of C<augment>:
       <% inner() %>
     </%method>
 
-To do no wrapping at all, a component could do:
+To do no wrapping at all, call the component class method L<no_wrap>:
 
-    <%method render>
-    % $.main();
-    </%method>
-
-or for convenience, the equivalent:
-
-    %% CLASS->no_wrap;
+    <%class>
+    CLASS->no_wrap;
+    </%class>
 
 =for html <a name="main" />
 
@@ -195,7 +191,9 @@ A convenience method that redefines L<render|/render> to call L<main|/main>
 instead of L<wrap|/wrap>, thus skipping any content wrapper inherited from
 parent.
 
-    %% CLASS->no_wrap;
+    <%class>
+    CLASS->no_wrap;
+    </%class>
 
 =item allow_path_info
 
@@ -203,6 +201,10 @@ This method is called when the request path has a path_info portion, to
 determine whether the path_info is allowed. Default is false. See
 L<Mason::Manual::RequestDispatch/Partial Paths|Mason::Manual::RequestDispatch>.
 
+    <%class>
+    CLASS->allow_path_info(1);
+    </%class>
+
 =back
 
 =head1 OTHER METHODS
