@@ -1,6 +1,6 @@
 package Mason::Filters::Standard;
 BEGIN {
-  $Mason::Filters::Standard::VERSION = '2.13';
+  $Mason::Filters::Standard::VERSION = '2.14';
 }
 use Mason::DynamicFilter;
 use Mason::Util;
@@ -86,12 +86,12 @@ Content|http://search.cpan.org/perldoc?HTML::Mason::Devel#Component_Calls_with_C
     % }}
 
   In list_items.mi:
-    <%args>
-    $.items
-    $.yield
-    </%args>
+    <%class>
+    has 'items';
+    has 'yield';
+    </%class>
 
-    % foreach my $item (@items) {
+    % foreach my $item (@{$.items}) {
     <% $.yield->($item) %>
     % }
 
