@@ -1,6 +1,6 @@
 package Mason::t::Autobase;
 BEGIN {
-  $Mason::t::Autobase::VERSION = '2.13';
+  $Mason::t::Autobase::VERSION = '2.14';
 }
 use Test::Class::Most parent => 'Mason::Test::Class';
 
@@ -176,7 +176,7 @@ Hello world
     $self->test_comp(
         path => '/wrap/subdir/subdir2/dont_wrap_me.mc',
         src  => '
-%% method wrap { $.main() }
+<%class>method wrap { $.main() }</%class>
 <% $self->hello() %>
 ',
         expect => 'Hello world'
@@ -184,7 +184,7 @@ Hello world
     $self->test_comp(
         path => '/wrap/subdir/subdir2/dont_wrap_me_either.mc',
         src  => '
-%% CLASS->no_wrap;
+<%class>CLASS->no_wrap;</%class>
 <% $self->hello() %>
 ',
         expect => 'Hello world'
