@@ -1,6 +1,6 @@
 package Mason::t::Errors;
 BEGIN {
-  $Mason::t::Errors::VERSION = '2.13';
+  $Mason::t::Errors::VERSION = '2.14';
 }
 use Test::Class::Most parent => 'Mason::Test::Class';
 
@@ -21,28 +21,23 @@ sub test_comp_errors : Tests {
         '<& /does/not/exist &>',
         qr/could not find component for path '\/does\/not\/exist' - component root is \Q[$root]\E/,
     );
-    $try->( '<%method>',                    qr/<%method> block requires a name/ );
-    $try->( '<%before>',                    qr/<%before> block requires a name/ );
-    $try->( '<%init>',                      qr/<%init> without matching <\/%init>/ );
-    $try->( '<%attr>',                      qr/unknown block '<%attr>'/ );
-    $try->( '<%blah>',                      qr/unknown block '<%blah>'/ );
-    $try->( '<%init foo>',                  qr/<%init> block does not take a name/ );
-    $try->( '<%',                           qr/'<%' without matching '%>'/ );
-    $try->( 'foo %>',                       qr/'%>' without matching '<%'/ );
-    $try->( '<& foo',                       qr/'<&' without matching '&>'/ );
-    $try->( 'foo &>',                       qr/'&>' without matching '<&'/ );
-    $try->( '%my $i = 1;',                  qr/% must be followed by whitespace/ );
-    $try->( '%%my $i = 1;',                 qr/%% must be followed by whitespace/ );
-    $try->( "%% if (1) {\nhi\n%% }",        qr/%%-lines cannot be used to surround content/ );
-    $try->( "<%5\n\n%>",                    qr/whitespace required after '<%' at .* line 1/ );
-    $try->( "<%\n\n5%>",                    qr/whitespace required before '%>' at .* line 3/ );
-    $try->( "<%args>\n\$\$abc\n</%args>",   qr/Invalid attribute line '\$\$abc' at .* line 2/ );
-    $try->( "<%args>\na\nb\n123\n</%args>", qr/Invalid attribute line '123' at .* line 4/ );
-    $try->( "<%args>\nargs\n</%args>",      qr/'args' is reserved.*attribute name/ );
-    $try->( "% \$.Upper {{\nHi",       qr/'{{' without matching '}}'/ );
-    $try->( "Hi\n% }}",                     qr/'}}' without matching '{{'/ );
-    $try->( '<%method 1a>Hi</%method>',     qr/Invalid method name '1a'/ );
-    $try->( '<%method cmeta>Hi</%method>',  qr/'cmeta' is reserved.*method name/ );
+    $try->( '<%method>',                   qr/<%method> block requires a name/ );
+    $try->( '<%before>',                   qr/<%before> block requires a name/ );
+    $try->( '<%init>',                     qr/<%init> without matching <\/%init>/ );
+    $try->( '<%attr>',                     qr/unknown block '<%attr>'/ );
+    $try->( '<%blah>',                     qr/unknown block '<%blah>'/ );
+    $try->( '<%init foo>',                 qr/<%init> block does not take a name/ );
+    $try->( '<%',                          qr/'<%' without matching '%>'/ );
+    $try->( 'foo %>',                      qr/'%>' without matching '<%'/ );
+    $try->( '<& foo',                      qr/'<&' without matching '&>'/ );
+    $try->( 'foo &>',                      qr/'&>' without matching '<&'/ );
+    $try->( '%my $i = 1;',                 qr/% must be followed by whitespace/ );
+    $try->( "<%5\n\n%>",                   qr/whitespace required after '<%' at .* line 1/ );
+    $try->( "<%\n\n5%>",                   qr/whitespace required before '%>' at .* line 3/ );
+    $try->( "% \$.Upper {{\nHi",      qr/'{{' without matching '}}'/ );
+    $try->( "Hi\n% }}",                    qr/'}}' without matching '{{'/ );
+    $try->( '<%method 1a>Hi</%method>',    qr/Invalid method name '1a'/ );
+    $try->( '<%method cmeta>Hi</%method>', qr/'cmeta' is reserved.*method name/ );
     $try->(
         "<%method a>Hi</%method>\n<%method a>Bye</%method>",
         qr/Duplicate definition of method 'a'/
@@ -61,9 +56,8 @@ sub test_comp_errors : Tests {
     $try->( "<%flags>\nextends => 'blah'\n</%flags>",
         qr/could not load '\/blah' for extends flag/ );
     $try->( "<%flags>\nextends => %foo\n</%flags>", qr/Global symbol/ );
-    $try->( '<% $foo %>',      qr/Global symbol "\$foo" requires explicit package name/ );
-    $try->( '%% die "bleah";', qr/bleah/ );
-    $try->( 'die "blargh";',   qr/blargh/, path => '/blargh.mp' );
+    $try->( '<% $foo %>', qr/Global symbol "\$foo" requires explicit package name/ );
+    $try->( 'die "blargh";', qr/blargh/, path => '/blargh.mp' );
 
     # Error line numbers
     #
